DirectoryTreeStateNotifier class
Manages the state of the directory tree, handling folder expansion and file operations.
- Inheritance
-
- Object
- ChangeNotifier
- DirectoryTreeStateNotifier
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isFolderCreation ↔ bool
-
Flag to determine if new entry is a folder
getter/setter pair
- newEntryPath ↔ String?
-
Path of the new entry being created
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
isUnfolded(
String dirPath, String rootPath) → bool - Checks if a folder is expanded or collapsed
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
startCreating(
String parentPath, bool folder) → void - Starts the creation process of a new folder or file
-
stopCreating(
) → void - Stops the creation process and clears the state
-
toggleFolder(
String dirPath, String rootPath) → void - Toggles folder expansion/collapse state
-
toString(
) → String -
A string representation of this object.
inherited
-
watchDirectory(
String directoryPath) → void - Watches the given directory for changes and updates the UI accordingly
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited