FoldableDirectoryTree class
A widget that displays a foldable directory tree, showing files and subdirectories.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FoldableDirectoryTree
Constructors
-
FoldableDirectoryTree({Key? key, required String rootPath, void onFileTap(File, TapDownDetails)?, void onFileSecondaryTap(File, TapDownDetails)?, void onDirTap(Directory, TapDownDetails)?, void onDirSecondaryTap(Directory, TapDownDetails)?, FolderStyle? folderStyle, FileStyle? fileStyle, List<
Widget> ? folderActions, List<Widget> ? fileActions, EditingFieldStyle? editingFieldStyle, bool enableCreateFileOption = false, bool enableCreateFolderOption = false, bool enableDeleteFileOption = false, bool enableDeleteFolderOption = false, Widget fileIconBuilder(String fileExtension)?}) -
const
Properties
- editingFieldStyle → EditingFieldStyle?
-
final
- enableCreateFileOption → bool
-
final
- enableCreateFolderOption → bool
-
final
- enableDeleteFileOption → bool
-
final
- enableDeleteFolderOption → bool
-
final
-
fileActions
→ List<
Widget> ? -
final
- fileIconBuilder → Widget Function(String fileExtension)?
-
final
- fileStyle → FileStyle?
-
final
-
folderActions
→ List<
Widget> ? -
final
- folderStyle → FolderStyle?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onDirSecondaryTap → void Function(Directory, TapDownDetails)?
-
final
- onDirTap → void Function(Directory, TapDownDetails)?
-
final
- onFileSecondaryTap → void Function(File, TapDownDetails)?
-
final
- onFileTap → void Function(File, TapDownDetails)?
-
final
- rootPath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FoldableDirectoryTree> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited